@@ -114,12 +114,8 @@ class Syfpeithi(APSSMEpitopePrediction):
         SYFPEITHI: database for MHC ligands and peptide motifs. Immunogenetics, 50(3-4), 213-219.
     """
     __alleles = frozenset(
-        ['HLA-B*15:10', 'HLA-B*41:01', 'HLA-B*37:01', 'HLA-B*27:05', 'HLA-B*38:01', 'HLA-A*02:01', 'HLA-B*47:01',
-         'HLA-A*26:01', 'HLA-B*37:01', 'HLA-DRB1*11:01', 'HLA-B*50:01', 'HLA-B*07:02', 'HLA-A*68:01', 'HLA-A*24:02',
-         'HLA-DRB1*15:01', 'HLA-B*15:01', 'HLA-B*45:01', 'HLA-A*11:01', 'HLA-A*03:01', 'HLA-B*40:01', 'HLA-DRB1*03:01',
-         'HLA-B*39:01', 'HLA-DRB1*01:01', 'HLA-B*51:01', 'HLA-B*39:02', 'HLA-B*08:01', 'HLA-B*18:01', 'HLA-B*44:02',
-         'HLA-B*49:01', 'HLA-DRB1*07:01', 'HLA-B*14:02', 'HLA-A*01:01'])
-    __supported_length = frozenset([8, 9, 10, 11])
+        ['HLA-A*01:01','HLA-A*02:01','HLA-A*03:01','HLA-A*11:01','HLA-A*24:02','HLA-A*26:01','HLA-A*31:01','HLA-A*32:01','HLA-A*33:01','HLA-A*66:01','HLA-A*68:01','HLA-B*07:02','HLA-B*08:01','HLA-B*13:02','HLA-B*14:02','HLA-B*15:01','HLA-B*15:16','HLA-B*18:01','HLA-B*27:05','HLA-B*27:09','HLA-B*35:01','HLA-B*37:01','HLA-B*38:01','HLA-B*39:01','HLA-B*39:02','HLA-B*40:01','HLA-B*40:02','HLA-B*41:01','HLA-B*44:02','HLA-B*45:01','HLA-B*47:01','HLA-B*49:01','HLA-B*50:01','HLA-B*51:01','HLA-B*53:01','HLA-B*57:01','HLA-B*58:01','HLA-B*58:02','HLA-C*01:02','HLA-C*02:02','HLA-C*03:03','HLA-C*03:04','HLA-C*04:01','HLA-C*05:01','HLA-C*06:01','HLA-C*06:02','HLA-C*07:01','HLA-C*07:02','HLA-C*08:02','HLA-C*12:03','HLA-C*14:02','HLA-C*15:02','HLA-C*16:01','HLA-C*17:01','HLA-DRB1*01:01','HLA-DRB1*03:01','HLA-DRB1*07:01','HLA-DRB1*11:01','HLA-DRB1*15:01','HLA-G*01:01','H-2-Db','H-2-Kb','H-2-Kd','H-2-Ld'])
+    __supported_length = frozenset([8, 9, 10, 11, 12, 13])
     __name = "syfpeithi"
     __version = "1.0"
 
